import { type MaybeComputedElementRef } from '@vueuse/core';
import { type MaybeComputedRef } from '@vueuse/shared';
import { Map, type MapOptions, type LatLngExpression, type LatLngBoundsExpression, type LatLng, type LatLngBounds, type LeafletEvent } from 'leaflet';
export interface UseLeafletMapOptions extends Omit<MapOptions, 'center' | 'zoom'> {
    center?: MaybeComputedRef<LatLngExpression | undefined>;
    zoom?: MaybeComputedRef<number | undefined>;
    bounds?: MaybeComputedRef<LatLngBoundsExpression | undefined>;
    useFly?: MaybeComputedRef<boolean | undefined>;
    factory?: (...args: unknown[]) => Map;
    onViewChanged?: ViewChangedCallback;
}
export interface ViewChangedEvent extends LeafletEvent {
    center: LatLng;
    zoom: number;
    bounds: LatLngBounds;
}
export type ViewChangedCallback = (event: ViewChangedEvent) => void;
export declare function useLeafletMap(element: MaybeComputedElementRef, options?: UseLeafletMapOptions): import("vue-demi").Ref<{
    getRenderer: (layer: import("leaflet").Path) => import("leaflet").Renderer;
    addControl: (control: import("leaflet").Control) => Map;
    removeControl: (control: import("leaflet").Control) => Map;
    addLayer: (layer: import("leaflet").Layer) => Map;
    removeLayer: (layer: import("leaflet").Layer) => Map;
    hasLayer: (layer: import("leaflet").Layer) => boolean;
    eachLayer: (fn: (layer: import("leaflet").Layer) => void, context?: any) => Map;
    openPopup: {
        (popup: import("leaflet").Popup): Map;
        (content: import("leaflet").Content, latlng: LatLngExpression, options?: import("leaflet").PopupOptions | undefined): Map;
    };
    closePopup: (popup?: import("leaflet").Popup | undefined) => Map;
    openTooltip: {
        (tooltip: import("leaflet").Tooltip): Map;
        (content: import("leaflet").Content, latlng: LatLngExpression, options?: import("leaflet").TooltipOptions | undefined): Map;
    };
    closeTooltip: (tooltip?: import("leaflet").Tooltip | undefined) => Map;
    setView: (center: LatLngExpression, zoom?: number | undefined, options?: import("leaflet").ZoomPanOptions | undefined) => Map;
    setZoom: (zoom: number, options?: import("leaflet").ZoomPanOptions | undefined) => Map;
    zoomIn: (delta?: number | undefined, options?: import("leaflet").ZoomOptions | undefined) => Map;
    zoomOut: (delta?: number | undefined, options?: import("leaflet").ZoomOptions | undefined) => Map;
    setZoomAround: (position: LatLngExpression | import("leaflet").Point, zoom: number, options?: import("leaflet").ZoomOptions | undefined) => Map;
    fitBounds: (bounds: LatLngBoundsExpression, options?: import("leaflet").FitBoundsOptions | undefined) => Map;
    fitWorld: (options?: import("leaflet").FitBoundsOptions | undefined) => Map;
    panTo: (latlng: LatLngExpression, options?: import("leaflet").PanOptions | undefined) => Map;
    panBy: (offset: import("leaflet").PointExpression, options?: import("leaflet").PanOptions | undefined) => Map;
    setMaxBounds: (bounds: LatLngBoundsExpression) => Map;
    setMinZoom: (zoom: number) => Map;
    setMaxZoom: (zoom: number) => Map;
    panInside: (latLng: LatLngExpression, options?: import("leaflet").PanInsideOptions | undefined) => Map;
    panInsideBounds: (bounds: LatLngBoundsExpression, options?: import("leaflet").PanOptions | undefined) => Map;
    invalidateSize: (options?: boolean | import("leaflet").InvalidateSizeOptions | undefined) => Map;
    stop: () => Map;
    flyTo: (latlng: LatLngExpression, zoom?: number | undefined, options?: import("leaflet").ZoomPanOptions | undefined) => Map;
    flyToBounds: (bounds: LatLngBoundsExpression, options?: import("leaflet").FitBoundsOptions | undefined) => Map;
    addHandler: (name: string, HandlerClass: typeof import("leaflet").Handler) => Map;
    remove: () => Map;
    createPane: (name: string, container?: HTMLElement | undefined) => HTMLElement;
    getPane: (pane: string | HTMLElement) => HTMLElement | undefined;
    getPanes: () => {
        [name: string]: HTMLElement;
    } & import("leaflet").DefaultMapPanes;
    getContainer: () => HTMLElement;
    whenReady: (fn: () => void, context?: any) => Map;
    getCenter: () => LatLng;
    getZoom: () => number;
    getBounds: () => LatLngBounds;
    getMinZoom: () => number;
    getMaxZoom: () => number;
    getBoundsZoom: (bounds: LatLngBoundsExpression, inside?: boolean | undefined, padding?: import("leaflet").Point | undefined) => number;
    getSize: () => import("leaflet").Point;
    getPixelBounds: () => import("leaflet").Bounds;
    getPixelOrigin: () => import("leaflet").Point;
    getPixelWorldBounds: (zoom?: number | undefined) => import("leaflet").Bounds;
    getZoomScale: (toZoom: number, fromZoom?: number | undefined) => number;
    getScaleZoom: (scale: number, fromZoom?: number | undefined) => number;
    project: (latlng: LatLngExpression, zoom?: number | undefined) => import("leaflet").Point;
    unproject: (point: import("leaflet").PointExpression, zoom?: number | undefined) => LatLng;
    layerPointToLatLng: (point: import("leaflet").PointExpression) => LatLng;
    latLngToLayerPoint: (latlng: LatLngExpression) => import("leaflet").Point;
    wrapLatLng: (latlng: LatLngExpression) => LatLng;
    wrapLatLngBounds: (bounds: LatLngBounds) => LatLngBounds;
    distance: (latlng1: LatLngExpression, latlng2: LatLngExpression) => number;
    containerPointToLayerPoint: (point: import("leaflet").PointExpression) => import("leaflet").Point;
    containerPointToLatLng: (point: import("leaflet").PointExpression) => LatLng;
    layerPointToContainerPoint: (point: import("leaflet").PointExpression) => import("leaflet").Point;
    latLngToContainerPoint: (latlng: LatLngExpression) => import("leaflet").Point;
    mouseEventToContainerPoint: (ev: MouseEvent) => import("leaflet").Point;
    mouseEventToLayerPoint: (ev: MouseEvent) => import("leaflet").Point;
    mouseEventToLatLng: (ev: MouseEvent) => LatLng;
    locate: (options?: import("leaflet").LocateOptions | undefined) => Map;
    stopLocate: () => Map;
    attributionControl: {
        setPrefix: (prefix: string | false) => import("leaflet").Control.Attribution;
        addAttribution: (text: string) => import("leaflet").Control.Attribution;
        removeAttribution: (text: string) => import("leaflet").Control.Attribution;
        options: {
            prefix?: string | boolean | undefined;
            position?: import("leaflet").ControlPosition | undefined;
        };
        getPosition: () => import("leaflet").ControlPosition;
        setPosition: (position: import("leaflet").ControlPosition) => import("leaflet").Control.Attribution;
        getContainer: () => HTMLElement | undefined;
        addTo: (map: Map) => import("leaflet").Control.Attribution;
        remove: () => import("leaflet").Control.Attribution;
        onAdd?: ((map: Map) => HTMLElement) | undefined;
        onRemove?: ((map: Map) => void) | undefined;
    };
    boxZoom: {
        enable: () => import("leaflet").Handler;
        disable: () => import("leaflet").Handler;
        enabled: () => boolean;
        addHooks?: (() => void) | undefined;
        removeHooks?: (() => void) | undefined;
    };
    doubleClickZoom: {
        enable: () => import("leaflet").Handler;
        disable: () => import("leaflet").Handler;
        enabled: () => boolean;
        addHooks?: (() => void) | undefined;
        removeHooks?: (() => void) | undefined;
    };
    dragging: {
        enable: () => import("leaflet").Handler;
        disable: () => import("leaflet").Handler;
        enabled: () => boolean;
        addHooks?: (() => void) | undefined;
        removeHooks?: (() => void) | undefined;
    };
    keyboard: {
        enable: () => import("leaflet").Handler;
        disable: () => import("leaflet").Handler;
        enabled: () => boolean;
        addHooks?: (() => void) | undefined;
        removeHooks?: (() => void) | undefined;
    };
    scrollWheelZoom: {
        enable: () => import("leaflet").Handler;
        disable: () => import("leaflet").Handler;
        enabled: () => boolean;
        addHooks?: (() => void) | undefined;
        removeHooks?: (() => void) | undefined;
    };
    tap?: {
        enable: () => import("leaflet").Handler;
        disable: () => import("leaflet").Handler;
        enabled: () => boolean;
        addHooks?: (() => void) | undefined;
        removeHooks?: (() => void) | undefined;
    } | undefined;
    touchZoom: {
        enable: () => import("leaflet").Handler;
        disable: () => import("leaflet").Handler;
        enabled: () => boolean;
        addHooks?: (() => void) | undefined;
        removeHooks?: (() => void) | undefined;
    };
    zoomControl: {
        options: {
            zoomInText?: string | undefined;
            zoomInTitle?: string | undefined;
            zoomOutText?: string | undefined;
            zoomOutTitle?: string | undefined;
            position?: import("leaflet").ControlPosition | undefined;
        };
        getPosition: () => import("leaflet").ControlPosition;
        setPosition: (position: import("leaflet").ControlPosition) => import("leaflet").Control.Zoom;
        getContainer: () => HTMLElement | undefined;
        addTo: (map: Map) => import("leaflet").Control.Zoom;
        remove: () => import("leaflet").Control.Zoom;
        onAdd?: ((map: Map) => HTMLElement) | undefined;
        onRemove?: ((map: Map) => void) | undefined;
    };
    options: {
        preferCanvas?: boolean | undefined;
        attributionControl?: boolean | undefined;
        zoomControl?: boolean | undefined;
        closePopupOnClick?: boolean | undefined;
        zoomSnap?: number | undefined;
        zoomDelta?: number | undefined;
        trackResize?: boolean | undefined;
        boxZoom?: boolean | undefined;
        doubleClickZoom?: import("leaflet").Zoom | undefined;
        dragging?: boolean | undefined;
        crs?: {
            latLngToPoint: (latlng: LatLngExpression, zoom: number) => import("leaflet").Point;
            pointToLatLng: (point: import("leaflet").PointExpression, zoom: number) => LatLng;
            project: (latlng: LatLng | import("leaflet").LatLngLiteral) => import("leaflet").Point;
            unproject: (point: import("leaflet").PointExpression) => LatLng;
            scale: (zoom: number) => number;
            zoom: (scale: number) => number;
            getProjectedBounds: (zoom: number) => import("leaflet").Bounds;
            distance: (latlng1: LatLngExpression, latlng2: LatLngExpression) => number;
            wrapLatLng: (latlng: LatLng | import("leaflet").LatLngLiteral) => LatLng;
            code?: string | undefined;
            wrapLng?: [number, number] | undefined;
            wrapLat?: [number, number] | undefined;
            infinite: boolean;
        } | undefined;
        center?: [number, number] | {
            equals: (otherLatLng: LatLngExpression, maxMargin?: number | undefined) => boolean;
            toString: () => string;
            distanceTo: (otherLatLng: LatLngExpression) => number;
            wrap: () => LatLng;
            toBounds: (sizeInMeters: number) => LatLngBounds;
            clone: () => LatLng;
            lat: number;
            lng: number;
            alt?: number | undefined;
        } | {
            lat: number;
            lng: number;
        } | undefined;
        zoom?: number | undefined;
        minZoom?: number | undefined;
        maxZoom?: number | undefined;
        layers?: {
            addTo: (map: Map | import("leaflet").LayerGroup<any>) => import("leaflet").Layer;
            remove: () => import("leaflet").Layer;
            removeFrom: (map: Map) => import("leaflet").Layer;
            getPane: (name?: string | undefined) => HTMLElement | undefined;
            addInteractiveTarget: (targetEl: HTMLElement) => import("leaflet").Layer;
            removeInteractiveTarget: (targetEl: HTMLElement) => import("leaflet").Layer;
            bindPopup: (content: import("leaflet").Popup | import("leaflet").Content | ((layer: import("leaflet").Layer) => import("leaflet").Content), options?: import("leaflet").PopupOptions | undefined) => import("leaflet").Layer;
            unbindPopup: () => import("leaflet").Layer;
            openPopup: (latlng?: LatLngExpression | undefined) => import("leaflet").Layer;
            closePopup: () => import("leaflet").Layer;
            togglePopup: () => import("leaflet").Layer;
            isPopupOpen: () => boolean;
            setPopupContent: (content: import("leaflet").Popup | import("leaflet").Content) => import("leaflet").Layer;
            getPopup: () => import("leaflet").Popup | undefined;
            bindTooltip: (content: import("leaflet").Content | import("leaflet").Tooltip | ((layer: import("leaflet").Layer) => import("leaflet").Content), options?: import("leaflet").TooltipOptions | undefined) => import("leaflet").Layer;
            unbindTooltip: () => import("leaflet").Layer;
            openTooltip: (latlng?: LatLngExpression | undefined) => import("leaflet").Layer;
            closeTooltip: () => import("leaflet").Layer;
            toggleTooltip: () => import("leaflet").Layer;
            isTooltipOpen: () => boolean;
            setTooltipContent: (content: import("leaflet").Content | import("leaflet").Tooltip) => import("leaflet").Layer;
            getTooltip: () => import("leaflet").Tooltip | undefined;
            onAdd: (map: Map) => import("leaflet").Layer;
            onRemove: (map: Map) => import("leaflet").Layer;
            getEvents?: (() => {
                [name: string]: import("leaflet").LeafletEventHandlerFn;
            }) | undefined;
            getAttribution?: (() => string | null) | undefined;
            beforeAdd?: ((map: Map) => import("leaflet").Layer) | undefined;
            on: {
                (type: "baselayerchange" | "overlayadd" | "overlayremove", fn: import("leaflet").LayersControlEventHandlerFn, context?: any): import("leaflet").Layer;
                (type: "layeradd" | "layerremove", fn: import("leaflet").LayerEventHandlerFn, context?: any): import("leaflet").Layer;
                (type: "drag" | "dragstart" | "error" | "load" | "unload" | "zoom" | "remove" | "zoomlevelschange" | "viewreset" | "zoomstart" | "movestart" | "move" | "zoomend" | "moveend" | "autopanstart" | "add" | "loading" | "update" | "down" | "predrag", fn: import("leaflet").LeafletEventHandlerFn, context?: any): import("leaflet").Layer;
                (type: "resize", fn: import("leaflet").ResizeEventHandlerFn, context?: any): import("leaflet").Layer;
                (type: "popupopen" | "popupclose", fn: import("leaflet").PopupEventHandlerFn, context?: any): import("leaflet").Layer;
                (type: "tooltipopen" | "tooltipclose", fn: import("leaflet").TooltipEventHandlerFn, context?: any): import("leaflet").Layer;
                (type: "locationerror", fn: import("leaflet").ErrorEventHandlerFn, context?: any): import("leaflet").Layer;
                (type: "locationfound", fn: import("leaflet").LocationEventHandlerFn, context?: any): import("leaflet").Layer;
                (type: "click" | "contextmenu" | "dblclick" | "mousedown" | "mousemove" | "mouseout" | "mouseover" | "mouseup" | "preclick", fn: import("leaflet").LeafletMouseEventHandlerFn, context?: any): import("leaflet").Layer;
                (type: "keydown" | "keypress" | "keyup", fn: import("leaflet").LeafletKeyboardEventHandlerFn, context?: any): import("leaflet").Layer;
                (type: "zoomanim", fn: import("leaflet").ZoomAnimEventHandlerFn, context?: any): import("leaflet").Layer;
                (type: "dragend", fn: import("leaflet").DragEndEventHandlerFn, context?: any): import("leaflet").Layer;
                (type: "tileunload" | "tileloadstart" | "tileload" | "tileabort", fn: import("leaflet").TileEventHandlerFn, context?: any): import("leaflet").Layer;
                (type: "tileerror", fn: import("leaflet").TileErrorEventHandlerFn, context?: any): import("leaflet").Layer;
                (type: string, fn: import("leaflet").LeafletEventHandlerFn, context?: any): import("leaflet").Layer;
                (eventMap: import("leaflet").LeafletEventHandlerFnMap): import("leaflet").Layer;
            };
            off: {
                (type: "baselayerchange" | "overlayadd" | "overlayremove", fn?: import("leaflet").LayersControlEventHandlerFn | undefined, context?: any): import("leaflet").Layer;
                (type: "layeradd" | "layerremove", fn?: import("leaflet").LayerEventHandlerFn | undefined, context?: any): import("leaflet").Layer;
                (type: "drag" | "dragstart" | "error" | "load" | "unload" | "zoom" | "remove" | "zoomlevelschange" | "viewreset" | "zoomstart" | "movestart" | "move" | "zoomend" | "moveend" | "autopanstart" | "add" | "loading" | "update" | "down" | "predrag", fn?: import("leaflet").LeafletEventHandlerFn | undefined, context?: any): import("leaflet").Layer;
                (type: "resize", fn?: import("leaflet").ResizeEventHandlerFn | undefined, context?: any): import("leaflet").Layer;
                (type: "popupopen" | "popupclose", fn?: import("leaflet").PopupEventHandlerFn | undefined, context?: any): import("leaflet").Layer;
                (type: "tooltipopen" | "tooltipclose", fn?: import("leaflet").TooltipEventHandlerFn | undefined, context?: any): import("leaflet").Layer;
                (type: "locationerror", fn?: import("leaflet").ErrorEventHandlerFn | undefined, context?: any): import("leaflet").Layer;
                (type: "locationfound", fn?: import("leaflet").LocationEventHandlerFn | undefined, context?: any): import("leaflet").Layer;
                (type: "click" | "contextmenu" | "dblclick" | "mousedown" | "mousemove" | "mouseout" | "mouseover" | "mouseup" | "preclick", fn?: import("leaflet").LeafletMouseEventHandlerFn | undefined, context?: any): import("leaflet").Layer;
                (type: "keydown" | "keypress" | "keyup", fn?: import("leaflet").LeafletKeyboardEventHandlerFn | undefined, context?: any): import("leaflet").Layer;
                (type: "zoomanim", fn?: import("leaflet").ZoomAnimEventHandlerFn | undefined, context?: any): import("leaflet").Layer;
                (type: "dragend", fn?: import("leaflet").DragEndEventHandlerFn | undefined, context?: any): import("leaflet").Layer;
                (type: "tileunload" | "tileloadstart" | "tileload" | "tileabort", fn?: import("leaflet").TileEventHandlerFn | undefined, context?: any): import("leaflet").Layer;
                (type: "tileerror", fn?: import("leaflet").TileErrorEventHandlerFn | undefined, context?: any): import("leaflet").Layer;
                (type: string, fn?: import("leaflet").LeafletEventHandlerFn | undefined, context?: any): import("leaflet").Layer;
                (eventMap: import("leaflet").LeafletEventHandlerFnMap): import("leaflet").Layer;
                (): import("leaflet").Layer;
            };
            fire: (type: string, data?: any, propagate?: boolean | undefined) => import("leaflet").Layer;
            listens: {
                (type: "click" | "contextmenu" | "dblclick" | "drag" | "dragend" | "dragstart" | "error" | "keydown" | "keypress" | "keyup" | "load" | "mousedown" | "mousemove" | "mouseout" | "mouseover" | "mouseup" | "resize" | "unload" | "zoom" | "remove" | "baselayerchange" | "overlayadd" | "overlayremove" | "layeradd" | "layerremove" | "zoomlevelschange" | "viewreset" | "zoomstart" | "movestart" | "move" | "zoomend" | "moveend" | "autopanstart" | "add" | "loading" | "update" | "down" | "predrag" | "popupopen" | "tooltipopen" | "tooltipclose" | "locationerror" | "locationfound" | "preclick" | "zoomanim" | "tileunload" | "tileloadstart" | "tileload" | "tileabort" | "tileerror", propagate?: boolean | undefined): boolean;
                (type: "baselayerchange" | "overlayadd" | "overlayremove", fn: import("leaflet").LayersControlEventHandlerFn, context?: any, propagate?: boolean | undefined): boolean;
                (type: "layeradd" | "layerremove", fn: import("leaflet").LayerEventHandlerFn, context?: any, propagate?: boolean | undefined): boolean;
                (type: "drag" | "dragstart" | "error" | "load" | "unload" | "zoom" | "remove" | "zoomlevelschange" | "viewreset" | "zoomstart" | "movestart" | "move" | "zoomend" | "moveend" | "autopanstart" | "add" | "loading" | "update" | "down" | "predrag", fn: import("leaflet").LeafletEventHandlerFn, context?: any, propagate?: boolean | undefined): boolean;
                (type: "resize", fn: import("leaflet").ResizeEventHandlerFn, context?: any, propagate?: boolean | undefined): boolean;
                (type: "popupopen" | "popupclose", fn: import("leaflet").PopupEventHandlerFn, context?: any, propagate?: boolean | undefined): boolean;
                (type: "tooltipopen" | "tooltipclose", fn: import("leaflet").TooltipEventHandlerFn, context?: any, propagate?: boolean | undefined): boolean;
                (type: "locationerror", fn: import("leaflet").ErrorEventHandlerFn, context?: any, propagate?: boolean | undefined): boolean;
                (type: "locationfound", fn: import("leaflet").LocationEventHandlerFn, context?: any, propagate?: boolean | undefined): boolean;
                (type: "click" | "contextmenu" | "dblclick" | "mousedown" | "mousemove" | "mouseout" | "mouseover" | "mouseup" | "preclick", fn: import("leaflet").LeafletMouseEventHandlerFn, context?: any, propagate?: boolean | undefined): boolean;
                (type: "keydown" | "keypress" | "keyup", fn: import("leaflet").LeafletKeyboardEventHandlerFn, context?: any, propagate?: boolean | undefined): boolean;
                (type: "zoomanim", fn: import("leaflet").ZoomAnimEventHandlerFn, context?: any, propagate?: boolean | undefined): boolean;
                (type: "dragend", fn: import("leaflet").DragEndEventHandlerFn, context?: any, propagate?: boolean | undefined): boolean;
                (type: "tileunload" | "tileloadstart" | "tileload" | "tileabort", fn: import("leaflet").TileEventHandlerFn, context?: any, propagate?: boolean | undefined): boolean;
                (type: "tileerror", fn: import("leaflet").TileEventHandlerFn, context?: any, propagate?: boolean | undefined): boolean;
                (type: string, fn: import("leaflet").LeafletEventHandlerFn, context?: any, propagate?: boolean | undefined): boolean;
            };
            once: {
                (type: "baselayerchange" | "overlayadd" | "overlayremove", fn: import("leaflet").LayersControlEventHandlerFn, context?: any): import("leaflet").Layer;
                (type: "layeradd" | "layerremove", fn: import("leaflet").LayerEventHandlerFn, context?: any): import("leaflet").Layer;
                (type: "drag" | "dragstart" | "error" | "load" | "unload" | "zoom" | "remove" | "zoomlevelschange" | "viewreset" | "zoomstart" | "movestart" | "move" | "zoomend" | "moveend" | "autopanstart" | "add" | "loading" | "update" | "down" | "predrag", fn: import("leaflet").LeafletEventHandlerFn, context?: any): import("leaflet").Layer;
                (type: "resize", fn: import("leaflet").ResizeEventHandlerFn, context?: any): import("leaflet").Layer;
                (type: "popupopen" | "popupclose", fn: import("leaflet").PopupEventHandlerFn, context?: any): import("leaflet").Layer;
                (type: "tooltipopen" | "tooltipclose", fn: import("leaflet").TooltipEventHandlerFn, context?: any): import("leaflet").Layer;
                (type: "locationerror", fn: import("leaflet").ErrorEventHandlerFn, context?: any): import("leaflet").Layer;
                (type: "locationfound", fn: import("leaflet").LocationEventHandlerFn, context?: any): import("leaflet").Layer;
                (type: "click" | "contextmenu" | "dblclick" | "mousedown" | "mousemove" | "mouseout" | "mouseover" | "mouseup" | "preclick", fn: import("leaflet").LeafletMouseEventHandlerFn, context?: any): import("leaflet").Layer;
                (type: "keydown" | "keypress" | "keyup", fn: import("leaflet").LeafletKeyboardEventHandlerFn, context?: any): import("leaflet").Layer;
                (type: "zoomanim", fn: import("leaflet").ZoomAnimEventHandlerFn, context?: any): import("leaflet").Layer;
                (type: "dragend", fn: import("leaflet").DragEndEventHandlerFn, context?: any): import("leaflet").Layer;
                (type: "tileunload" | "tileloadstart" | "tileload" | "tileabort", fn: import("leaflet").TileEventHandlerFn, context?: any): import("leaflet").Layer;
                (type: "tileerror", fn: import("leaflet").TileEventHandlerFn, context?: any): import("leaflet").Layer;
                (type: string, fn: import("leaflet").LeafletEventHandlerFn, context?: any): import("leaflet").Layer;
                (eventMap: import("leaflet").LeafletEventHandlerFnMap): import("leaflet").Layer;
            };
            addEventParent: (obj: import("leaflet").Evented) => import("leaflet").Layer;
            removeEventParent: (obj: import("leaflet").Evented) => import("leaflet").Layer;
            addEventListener: {
                (type: "baselayerchange" | "overlayadd" | "overlayremove", fn: import("leaflet").LayersControlEventHandlerFn, context?: any): import("leaflet").Layer;
                (type: "layeradd" | "layerremove", fn: import("leaflet").LayerEventHandlerFn, context?: any): import("leaflet").Layer;
                (type: "drag" | "dragstart" | "error" | "load" | "unload" | "zoom" | "remove" | "zoomlevelschange" | "viewreset" | "zoomstart" | "movestart" | "move" | "zoomend" | "moveend" | "autopanstart" | "add" | "loading" | "update" | "down" | "predrag", fn: import("leaflet").LeafletEventHandlerFn, context?: any): import("leaflet").Layer;
                (type: "resize", fn: import("leaflet").ResizeEventHandlerFn, context?: any): import("leaflet").Layer;
                (type: "popupopen" | "popupclose", fn: import("leaflet").PopupEventHandlerFn, context?: any): import("leaflet").Layer;
                (type: "tooltipopen" | "tooltipclose", fn: import("leaflet").TooltipEventHandlerFn, context?: any): import("leaflet").Layer;
                (type: "locationerror", fn: import("leaflet").ErrorEventHandlerFn, context?: any): import("leaflet").Layer;
                (type: "locationfound", fn: import("leaflet").LocationEventHandlerFn, context?: any): import("leaflet").Layer;
                (type: "click" | "contextmenu" | "dblclick" | "mousedown" | "mousemove" | "mouseout" | "mouseover" | "mouseup" | "preclick", fn: import("leaflet").LeafletMouseEventHandlerFn, context?: any): import("leaflet").Layer;
                (type: "keydown" | "keypress" | "keyup", fn: import("leaflet").LeafletKeyboardEventHandlerFn, context?: any): import("leaflet").Layer;
                (type: "zoomanim", fn: import("leaflet").ZoomAnimEventHandlerFn, context?: any): import("leaflet").Layer;
                (type: "dragend", fn: import("leaflet").DragEndEventHandlerFn, context?: any): import("leaflet").Layer;
                (type: "tileunload" | "tileloadstart" | "tileload" | "tileabort", fn: import("leaflet").TileEventHandlerFn, context?: any): import("leaflet").Layer;
                (type: "tileerror", fn: import("leaflet").TileErrorEventHandlerFn, context?: any): import("leaflet").Layer;
                (type: string, fn: import("leaflet").LeafletEventHandlerFn, context?: any): import("leaflet").Layer;
                (eventMap: import("leaflet").LeafletEventHandlerFnMap): import("leaflet").Layer;
            };
            removeEventListener: {
                (type: "baselayerchange" | "overlayadd" | "overlayremove", fn?: import("leaflet").LayersControlEventHandlerFn | undefined, context?: any): import("leaflet").Layer;
                (type: "layeradd" | "layerremove", fn?: import("leaflet").LayerEventHandlerFn | undefined, context?: any): import("leaflet").Layer;
                (type: "drag" | "dragstart" | "error" | "load" | "unload" | "zoom" | "remove" | "zoomlevelschange" | "viewreset" | "zoomstart" | "movestart" | "move" | "zoomend" | "moveend" | "autopanstart" | "add" | "loading" | "update" | "down" | "predrag", fn?: import("leaflet").LeafletEventHandlerFn | undefined, context?: any): import("leaflet").Layer;
                (type: "resize", fn?: import("leaflet").ResizeEventHandlerFn | undefined, context?: any): import("leaflet").Layer;
                (type: "popupopen" | "popupclose", fn?: import("leaflet").PopupEventHandlerFn | undefined, context?: any): import("leaflet").Layer;
                (type: "tooltipopen" | "tooltipclose", fn?: import("leaflet").TooltipEventHandlerFn | undefined, context?: any): import("leaflet").Layer;
                (type: "locationerror", fn?: import("leaflet").ErrorEventHandlerFn | undefined, context?: any): import("leaflet").Layer;
                (type: "locationfound", fn?: import("leaflet").LocationEventHandlerFn | undefined, context?: any): import("leaflet").Layer;
                (type: "click" | "contextmenu" | "dblclick" | "mousedown" | "mousemove" | "mouseout" | "mouseover" | "mouseup" | "preclick", fn?: import("leaflet").LeafletMouseEventHandlerFn | undefined, context?: any): import("leaflet").Layer;
                (type: "keydown" | "keypress" | "keyup", fn?: import("leaflet").LeafletKeyboardEventHandlerFn | undefined, context?: any): import("leaflet").Layer;
                (type: "zoomanim", fn?: import("leaflet").ZoomAnimEventHandlerFn | undefined, context?: any): import("leaflet").Layer;
                (type: "dragend", fn?: import("leaflet").DragEndEventHandlerFn | undefined, context?: any): import("leaflet").Layer;
                (type: "tileunload" | "tileloadstart" | "tileload" | "tileabort", fn?: import("leaflet").TileEventHandlerFn | undefined, context?: any): import("leaflet").Layer;
                (type: "tileerror", fn?: import("leaflet").TileErrorEventHandlerFn | undefined, context?: any): import("leaflet").Layer;
                (type: string, fn?: import("leaflet").LeafletEventHandlerFn | undefined, context?: any): import("leaflet").Layer;
                (eventMap: import("leaflet").LeafletEventHandlerFnMap): import("leaflet").Layer;
            };
            clearAllEventListeners: () => import("leaflet").Layer;
            addOneTimeEventListener: {
                (type: "baselayerchange" | "overlayadd" | "overlayremove", fn: import("leaflet").LayersControlEventHandlerFn, context?: any): import("leaflet").Layer;
                (type: "layeradd" | "layerremove", fn: import("leaflet").LayerEventHandlerFn, context?: any): import("leaflet").Layer;
                (type: "drag" | "dragstart" | "error" | "load" | "unload" | "zoom" | "remove" | "zoomlevelschange" | "viewreset" | "zoomstart" | "movestart" | "move" | "zoomend" | "moveend" | "autopanstart" | "add" | "loading" | "update" | "down" | "predrag", fn: import("leaflet").LeafletEventHandlerFn, context?: any): import("leaflet").Layer;
                (type: "resize", fn: import("leaflet").ResizeEventHandlerFn, context?: any): import("leaflet").Layer;
                (type: "popupopen" | "popupclose", fn: import("leaflet").PopupEventHandlerFn, context?: any): import("leaflet").Layer;
                (type: "tooltipopen" | "tooltipclose", fn: import("leaflet").TooltipEventHandlerFn, context?: any): import("leaflet").Layer;
                (type: "locationerror", fn: import("leaflet").ErrorEventHandlerFn, context?: any): import("leaflet").Layer;
                (type: "locationfound", fn: import("leaflet").LocationEventHandlerFn, context?: any): import("leaflet").Layer;
                (type: "click" | "contextmenu" | "dblclick" | "mousedown" | "mousemove" | "mouseout" | "mouseover" | "mouseup" | "preclick", fn: import("leaflet").LeafletMouseEventHandlerFn, context?: any): import("leaflet").Layer;
                (type: "keydown" | "keypress" | "keyup", fn: import("leaflet").LeafletKeyboardEventHandlerFn, context?: any): import("leaflet").Layer;
                (type: "zoomanim", fn: import("leaflet").ZoomAnimEventHandlerFn, context?: any): import("leaflet").Layer;
                (type: "dragend", fn: import("leaflet").DragEndEventHandlerFn, context?: any): import("leaflet").Layer;
                (type: "tileunload" | "tileloadstart" | "tileload" | "tileabort", fn: import("leaflet").TileEventHandlerFn, context?: any): import("leaflet").Layer;
                (type: "tileerror", fn: import("leaflet").TileErrorEventHandlerFn, context?: any): import("leaflet").Layer;
                (type: string, fn: import("leaflet").LeafletEventHandlerFn, context?: any): import("leaflet").Layer;
                (eventMap: import("leaflet").LeafletEventHandlerFnMap): import("leaflet").Layer;
            };
            fireEvent: (type: string, data?: any, propagate?: boolean | undefined) => import("leaflet").Layer;
            hasEventListeners: (type: string) => boolean;
        }[] | undefined;
        maxBounds?: {
            extend: (latlngOrBounds: LatLngExpression | LatLngBoundsExpression) => LatLngBounds;
            pad: (bufferRatio: number) => LatLngBounds;
            getCenter: () => LatLng;
            getSouthWest: () => LatLng;
            getNorthEast: () => LatLng;
            getNorthWest: () => LatLng;
            getSouthEast: () => LatLng;
            getWest: () => number;
            getSouth: () => number;
            getEast: () => number;
            getNorth: () => number;
            contains: (otherBoundsOrLatLng: LatLngExpression | LatLngBoundsExpression) => boolean;
            intersects: (otherBounds: LatLngBoundsExpression) => boolean;
            overlaps: (otherBounds: LatLngBoundsExpression) => boolean;
            toBBoxString: () => string;
            equals: (otherBounds: LatLngBoundsExpression) => boolean;
            isValid: () => boolean;
        } | [number, number][] | undefined;
        renderer?: {
            options: {
                padding?: number | undefined;
                tolerance?: number | undefined;
                pane?: string | undefined;
                attribution?: string | undefined;
            };
            addTo: (map: Map | import("leaflet").LayerGroup<any>) => import("leaflet").Renderer;
            remove: () => import("leaflet").Renderer;
            removeFrom: (map: Map) => import("leaflet").Renderer;
            getPane: (name?: string | undefined) => HTMLElement | undefined;
            addInteractiveTarget: (targetEl: HTMLElement) => import("leaflet").Renderer;
            removeInteractiveTarget: (targetEl: HTMLElement) => import("leaflet").Renderer;
            bindPopup: (content: import("leaflet").Popup | import("leaflet").Content | ((layer: import("leaflet").Layer) => import("leaflet").Content), options?: import("leaflet").PopupOptions | undefined) => import("leaflet").Renderer;
            unbindPopup: () => import("leaflet").Renderer;
            openPopup: (latlng?: LatLngExpression | undefined) => import("leaflet").Renderer;
            closePopup: () => import("leaflet").Renderer;
            togglePopup: () => import("leaflet").Renderer;
            isPopupOpen: () => boolean;
            setPopupContent: (content: import("leaflet").Popup | import("leaflet").Content) => import("leaflet").Renderer;
            getPopup: () => import("leaflet").Popup | undefined;
            bindTooltip: (content: import("leaflet").Content | import("leaflet").Tooltip | ((layer: import("leaflet").Layer) => import("leaflet").Content), options?: import("leaflet").TooltipOptions | undefined) => import("leaflet").Renderer;
            unbindTooltip: () => import("leaflet").Renderer;
            openTooltip: (latlng?: LatLngExpression | undefined) => import("leaflet").Renderer;
            closeTooltip: () => import("leaflet").Renderer;
            toggleTooltip: () => import("leaflet").Renderer;
            isTooltipOpen: () => boolean;
            setTooltipContent: (content: import("leaflet").Content | import("leaflet").Tooltip) => import("leaflet").Renderer;
            getTooltip: () => import("leaflet").Tooltip | undefined;
            onAdd: (map: Map) => import("leaflet").Renderer;
            onRemove: (map: Map) => import("leaflet").Renderer;
            getEvents?: (() => {
                [name: string]: import("leaflet").LeafletEventHandlerFn;
            }) | undefined;
            getAttribution?: (() => string | null) | undefined;
            beforeAdd?: ((map: Map) => import("leaflet").Renderer) | undefined;
            on: {
                (type: "baselayerchange" | "overlayadd" | "overlayremove", fn: import("leaflet").LayersControlEventHandlerFn, context?: any): import("leaflet").Renderer;
                (type: "layeradd" | "layerremove", fn: import("leaflet").LayerEventHandlerFn, context?: any): import("leaflet").Renderer;
                (type: "drag" | "dragstart" | "error" | "load" | "unload" | "zoom" | "remove" | "zoomlevelschange" | "viewreset" | "zoomstart" | "movestart" | "move" | "zoomend" | "moveend" | "autopanstart" | "add" | "loading" | "update" | "down" | "predrag", fn: import("leaflet").LeafletEventHandlerFn, context?: any): import("leaflet").Renderer;
                (type: "resize", fn: import("leaflet").ResizeEventHandlerFn, context?: any): import("leaflet").Renderer;
                (type: "popupopen" | "popupclose", fn: import("leaflet").PopupEventHandlerFn, context?: any): import("leaflet").Renderer;
                (type: "tooltipopen" | "tooltipclose", fn: import("leaflet").TooltipEventHandlerFn, context?: any): import("leaflet").Renderer;
                (type: "locationerror", fn: import("leaflet").ErrorEventHandlerFn, context?: any): import("leaflet").Renderer;
                (type: "locationfound", fn: import("leaflet").LocationEventHandlerFn, context?: any): import("leaflet").Renderer;
                (type: "click" | "contextmenu" | "dblclick" | "mousedown" | "mousemove" | "mouseout" | "mouseover" | "mouseup" | "preclick", fn: import("leaflet").LeafletMouseEventHandlerFn, context?: any): import("leaflet").Renderer;
                (type: "keydown" | "keypress" | "keyup", fn: import("leaflet").LeafletKeyboardEventHandlerFn, context?: any): import("leaflet").Renderer;
                (type: "zoomanim", fn: import("leaflet").ZoomAnimEventHandlerFn, context?: any): import("leaflet").Renderer;
                (type: "dragend", fn: import("leaflet").DragEndEventHandlerFn, context?: any): import("leaflet").Renderer;
                (type: "tileunload" | "tileloadstart" | "tileload" | "tileabort", fn: import("leaflet").TileEventHandlerFn, context?: any): import("leaflet").Renderer;
                (type: "tileerror", fn: import("leaflet").TileErrorEventHandlerFn, context?: any): import("leaflet").Renderer;
                (type: string, fn: import("leaflet").LeafletEventHandlerFn, context?: any): import("leaflet").Renderer;
                (eventMap: import("leaflet").LeafletEventHandlerFnMap): import("leaflet").Renderer;
            };
            off: {
                (type: "baselayerchange" | "overlayadd" | "overlayremove", fn?: import("leaflet").LayersControlEventHandlerFn | undefined, context?: any): import("leaflet").Renderer;
                (type: "layeradd" | "layerremove", fn?: import("leaflet").LayerEventHandlerFn | undefined, context?: any): import("leaflet").Renderer;
                (type: "drag" | "dragstart" | "error" | "load" | "unload" | "zoom" | "remove" | "zoomlevelschange" | "viewreset" | "zoomstart" | "movestart" | "move" | "zoomend" | "moveend" | "autopanstart" | "add" | "loading" | "update" | "down" | "predrag", fn?: import("leaflet").LeafletEventHandlerFn | undefined, context?: any): import("leaflet").Renderer;
                (type: "resize", fn?: import("leaflet").ResizeEventHandlerFn | undefined, context?: any): import("leaflet").Renderer;
                (type: "popupopen" | "popupclose", fn?: import("leaflet").PopupEventHandlerFn | undefined, context?: any): import("leaflet").Renderer;
                (type: "tooltipopen" | "tooltipclose", fn?: import("leaflet").TooltipEventHandlerFn | undefined, context?: any): import("leaflet").Renderer;
                (type: "locationerror", fn?: import("leaflet").ErrorEventHandlerFn | undefined, context?: any): import("leaflet").Renderer;
                (type: "locationfound", fn?: import("leaflet").LocationEventHandlerFn | undefined, context?: any): import("leaflet").Renderer;
                (type: "click" | "contextmenu" | "dblclick" | "mousedown" | "mousemove" | "mouseout" | "mouseover" | "mouseup" | "preclick", fn?: import("leaflet").LeafletMouseEventHandlerFn | undefined, context?: any): import("leaflet").Renderer;
                (type: "keydown" | "keypress" | "keyup", fn?: import("leaflet").LeafletKeyboardEventHandlerFn | undefined, context?: any): import("leaflet").Renderer;
                (type: "zoomanim", fn?: import("leaflet").ZoomAnimEventHandlerFn | undefined, context?: any): import("leaflet").Renderer;
                (type: "dragend", fn?: import("leaflet").DragEndEventHandlerFn | undefined, context?: any): import("leaflet").Renderer;
                (type: "tileunload" | "tileloadstart" | "tileload" | "tileabort", fn?: import("leaflet").TileEventHandlerFn | undefined, context?: any): import("leaflet").Renderer;
                (type: "tileerror", fn?: import("leaflet").TileErrorEventHandlerFn | undefined, context?: any): import("leaflet").Renderer;
                (type: string, fn?: import("leaflet").LeafletEventHandlerFn | undefined, context?: any): import("leaflet").Renderer;
                (eventMap: import("leaflet").LeafletEventHandlerFnMap): import("leaflet").Renderer;
                (): import("leaflet").Renderer;
            };
            fire: (type: string, data?: any, propagate?: boolean | undefined) => import("leaflet").Renderer;
            listens: {
                (type: "click" | "contextmenu" | "dblclick" | "drag" | "dragend" | "dragstart" | "error" | "keydown" | "keypress" | "keyup" | "load" | "mousedown" | "mousemove" | "mouseout" | "mouseover" | "mouseup" | "resize" | "unload" | "zoom" | "remove" | "baselayerchange" | "overlayadd" | "overlayremove" | "layeradd" | "layerremove" | "zoomlevelschange" | "viewreset" | "zoomstart" | "movestart" | "move" | "zoomend" | "moveend" | "autopanstart" | "add" | "loading" | "update" | "down" | "predrag" | "popupopen" | "tooltipopen" | "tooltipclose" | "locationerror" | "locationfound" | "preclick" | "zoomanim" | "tileunload" | "tileloadstart" | "tileload" | "tileabort" | "tileerror", propagate?: boolean | undefined): boolean;
                (type: "baselayerchange" | "overlayadd" | "overlayremove", fn: import("leaflet").LayersControlEventHandlerFn, context?: any, propagate?: boolean | undefined): boolean;
                (type: "layeradd" | "layerremove", fn: import("leaflet").LayerEventHandlerFn, context?: any, propagate?: boolean | undefined): boolean;
                (type: "drag" | "dragstart" | "error" | "load" | "unload" | "zoom" | "remove" | "zoomlevelschange" | "viewreset" | "zoomstart" | "movestart" | "move" | "zoomend" | "moveend" | "autopanstart" | "add" | "loading" | "update" | "down" | "predrag", fn: import("leaflet").LeafletEventHandlerFn, context?: any, propagate?: boolean | undefined): boolean;
                (type: "resize", fn: import("leaflet").ResizeEventHandlerFn, context?: any, propagate?: boolean | undefined): boolean;
                (type: "popupopen" | "popupclose", fn: import("leaflet").PopupEventHandlerFn, context?: any, propagate?: boolean | undefined): boolean;
                (type: "tooltipopen" | "tooltipclose", fn: import("leaflet").TooltipEventHandlerFn, context?: any, propagate?: boolean | undefined): boolean;
                (type: "locationerror", fn: import("leaflet").ErrorEventHandlerFn, context?: any, propagate?: boolean | undefined): boolean;
                (type: "locationfound", fn: import("leaflet").LocationEventHandlerFn, context?: any, propagate?: boolean | undefined): boolean;
                (type: "click" | "contextmenu" | "dblclick" | "mousedown" | "mousemove" | "mouseout" | "mouseover" | "mouseup" | "preclick", fn: import("leaflet").LeafletMouseEventHandlerFn, context?: any, propagate?: boolean | undefined): boolean;
                (type: "keydown" | "keypress" | "keyup", fn: import("leaflet").LeafletKeyboardEventHandlerFn, context?: any, propagate?: boolean | undefined): boolean;
                (type: "zoomanim", fn: import("leaflet").ZoomAnimEventHandlerFn, context?: any, propagate?: boolean | undefined): boolean;
                (type: "dragend", fn: import("leaflet").DragEndEventHandlerFn, context?: any, propagate?: boolean | undefined): boolean;
                (type: "tileunload" | "tileloadstart" | "tileload" | "tileabort", fn: import("leaflet").TileEventHandlerFn, context?: any, propagate?: boolean | undefined): boolean;
                (type: "tileerror", fn: import("leaflet").TileEventHandlerFn, context?: any, propagate?: boolean | undefined): boolean;
                (type: string, fn: import("leaflet").LeafletEventHandlerFn, context?: any, propagate?: boolean | undefined): boolean;
            };
            once: {
                (type: "baselayerchange" | "overlayadd" | "overlayremove", fn: import("leaflet").LayersControlEventHandlerFn, context?: any): import("leaflet").Renderer;
                (type: "layeradd" | "layerremove", fn: import("leaflet").LayerEventHandlerFn, context?: any): import("leaflet").Renderer;
                (type: "drag" | "dragstart" | "error" | "load" | "unload" | "zoom" | "remove" | "zoomlevelschange" | "viewreset" | "zoomstart" | "movestart" | "move" | "zoomend" | "moveend" | "autopanstart" | "add" | "loading" | "update" | "down" | "predrag", fn: import("leaflet").LeafletEventHandlerFn, context?: any): import("leaflet").Renderer;
                (type: "resize", fn: import("leaflet").ResizeEventHandlerFn, context?: any): import("leaflet").Renderer;
                (type: "popupopen" | "popupclose", fn: import("leaflet").PopupEventHandlerFn, context?: any): import("leaflet").Renderer;
                (type: "tooltipopen" | "tooltipclose", fn: import("leaflet").TooltipEventHandlerFn, context?: any): import("leaflet").Renderer;
                (type: "locationerror", fn: import("leaflet").ErrorEventHandlerFn, context?: any): import("leaflet").Renderer;
                (type: "locationfound", fn: import("leaflet").LocationEventHandlerFn, context?: any): import("leaflet").Renderer;
                (type: "click" | "contextmenu" | "dblclick" | "mousedown" | "mousemove" | "mouseout" | "mouseover" | "mouseup" | "preclick", fn: import("leaflet").LeafletMouseEventHandlerFn, context?: any): import("leaflet").Renderer;
                (type: "keydown" | "keypress" | "keyup", fn: import("leaflet").LeafletKeyboardEventHandlerFn, context?: any): import("leaflet").Renderer;
                (type: "zoomanim", fn: import("leaflet").ZoomAnimEventHandlerFn, context?: any): import("leaflet").Renderer;
                (type: "dragend", fn: import("leaflet").DragEndEventHandlerFn, context?: any): import("leaflet").Renderer;
                (type: "tileunload" | "tileloadstart" | "tileload" | "tileabort", fn: import("leaflet").TileEventHandlerFn, context?: any): import("leaflet").Renderer;
                (type: "tileerror", fn: import("leaflet").TileEventHandlerFn, context?: any): import("leaflet").Renderer;
                (type: string, fn: import("leaflet").LeafletEventHandlerFn, context?: any): import("leaflet").Renderer;
                (eventMap: import("leaflet").LeafletEventHandlerFnMap): import("leaflet").Renderer;
            };
            addEventParent: (obj: import("leaflet").Evented) => import("leaflet").Renderer;
            removeEventParent: (obj: import("leaflet").Evented) => import("leaflet").Renderer;
            addEventListener: {
                (type: "baselayerchange" | "overlayadd" | "overlayremove", fn: import("leaflet").LayersControlEventHandlerFn, context?: any): import("leaflet").Renderer;
                (type: "layeradd" | "layerremove", fn: import("leaflet").LayerEventHandlerFn, context?: any): import("leaflet").Renderer;
                (type: "drag" | "dragstart" | "error" | "load" | "unload" | "zoom" | "remove" | "zoomlevelschange" | "viewreset" | "zoomstart" | "movestart" | "move" | "zoomend" | "moveend" | "autopanstart" | "add" | "loading" | "update" | "down" | "predrag", fn: import("leaflet").LeafletEventHandlerFn, context?: any): import("leaflet").Renderer;
                (type: "resize", fn: import("leaflet").ResizeEventHandlerFn, context?: any): import("leaflet").Renderer;
                (type: "popupopen" | "popupclose", fn: import("leaflet").PopupEventHandlerFn, context?: any): import("leaflet").Renderer;
                (type: "tooltipopen" | "tooltipclose", fn: import("leaflet").TooltipEventHandlerFn, context?: any): import("leaflet").Renderer;
                (type: "locationerror", fn: import("leaflet").ErrorEventHandlerFn, context?: any): import("leaflet").Renderer;
                (type: "locationfound", fn: import("leaflet").LocationEventHandlerFn, context?: any): import("leaflet").Renderer;
                (type: "click" | "contextmenu" | "dblclick" | "mousedown" | "mousemove" | "mouseout" | "mouseover" | "mouseup" | "preclick", fn: import("leaflet").LeafletMouseEventHandlerFn, context?: any): import("leaflet").Renderer;
                (type: "keydown" | "keypress" | "keyup", fn: import("leaflet").LeafletKeyboardEventHandlerFn, context?: any): import("leaflet").Renderer;
                (type: "zoomanim", fn: import("leaflet").ZoomAnimEventHandlerFn, context?: any): import("leaflet").Renderer;
                (type: "dragend", fn: import("leaflet").DragEndEventHandlerFn, context?: any): import("leaflet").Renderer;
                (type: "tileunload" | "tileloadstart" | "tileload" | "tileabort", fn: import("leaflet").TileEventHandlerFn, context?: any): import("leaflet").Renderer;
                (type: "tileerror", fn: import("leaflet").TileErrorEventHandlerFn, context?: any): import("leaflet").Renderer;
                (type: string, fn: import("leaflet").LeafletEventHandlerFn, context?: any): import("leaflet").Renderer;
                (eventMap: import("leaflet").LeafletEventHandlerFnMap): import("leaflet").Renderer;
            };
            removeEventListener: {
                (type: "baselayerchange" | "overlayadd" | "overlayremove", fn?: import("leaflet").LayersControlEventHandlerFn | undefined, context?: any): import("leaflet").Renderer;
                (type: "layeradd" | "layerremove", fn?: import("leaflet").LayerEventHandlerFn | undefined, context?: any): import("leaflet").Renderer;
                (type: "drag" | "dragstart" | "error" | "load" | "unload" | "zoom" | "remove" | "zoomlevelschange" | "viewreset" | "zoomstart" | "movestart" | "move" | "zoomend" | "moveend" | "autopanstart" | "add" | "loading" | "update" | "down" | "predrag", fn?: import("leaflet").LeafletEventHandlerFn | undefined, context?: any): import("leaflet").Renderer;
                (type: "resize", fn?: import("leaflet").ResizeEventHandlerFn | undefined, context?: any): import("leaflet").Renderer;
                (type: "popupopen" | "popupclose", fn?: import("leaflet").PopupEventHandlerFn | undefined, context?: any): import("leaflet").Renderer;
                (type: "tooltipopen" | "tooltipclose", fn?: import("leaflet").TooltipEventHandlerFn | undefined, context?: any): import("leaflet").Renderer;
                (type: "locationerror", fn?: import("leaflet").ErrorEventHandlerFn | undefined, context?: any): import("leaflet").Renderer;
                (type: "locationfound", fn?: import("leaflet").LocationEventHandlerFn | undefined, context?: any): import("leaflet").Renderer;
                (type: "click" | "contextmenu" | "dblclick" | "mousedown" | "mousemove" | "mouseout" | "mouseover" | "mouseup" | "preclick", fn?: import("leaflet").LeafletMouseEventHandlerFn | undefined, context?: any): import("leaflet").Renderer;
                (type: "keydown" | "keypress" | "keyup", fn?: import("leaflet").LeafletKeyboardEventHandlerFn | undefined, context?: any): import("leaflet").Renderer;
                (type: "zoomanim", fn?: import("leaflet").ZoomAnimEventHandlerFn | undefined, context?: any): import("leaflet").Renderer;
                (type: "dragend", fn?: import("leaflet").DragEndEventHandlerFn | undefined, context?: any): import("leaflet").Renderer;
                (type: "tileunload" | "tileloadstart" | "tileload" | "tileabort", fn?: import("leaflet").TileEventHandlerFn | undefined, context?: any): import("leaflet").Renderer;
                (type: "tileerror", fn?: import("leaflet").TileErrorEventHandlerFn | undefined, context?: any): import("leaflet").Renderer;
                (type: string, fn?: import("leaflet").LeafletEventHandlerFn | undefined, context?: any): import("leaflet").Renderer;
                (eventMap: import("leaflet").LeafletEventHandlerFnMap): import("leaflet").Renderer;
            };
            clearAllEventListeners: () => import("leaflet").Renderer;
            addOneTimeEventListener: {
                (type: "baselayerchange" | "overlayadd" | "overlayremove", fn: import("leaflet").LayersControlEventHandlerFn, context?: any): import("leaflet").Renderer;
                (type: "layeradd" | "layerremove", fn: import("leaflet").LayerEventHandlerFn, context?: any): import("leaflet").Renderer;
                (type: "drag" | "dragstart" | "error" | "load" | "unload" | "zoom" | "remove" | "zoomlevelschange" | "viewreset" | "zoomstart" | "movestart" | "move" | "zoomend" | "moveend" | "autopanstart" | "add" | "loading" | "update" | "down" | "predrag", fn: import("leaflet").LeafletEventHandlerFn, context?: any): import("leaflet").Renderer;
                (type: "resize", fn: import("leaflet").ResizeEventHandlerFn, context?: any): import("leaflet").Renderer;
                (type: "popupopen" | "popupclose", fn: import("leaflet").PopupEventHandlerFn, context?: any): import("leaflet").Renderer;
                (type: "tooltipopen" | "tooltipclose", fn: import("leaflet").TooltipEventHandlerFn, context?: any): import("leaflet").Renderer;
                (type: "locationerror", fn: import("leaflet").ErrorEventHandlerFn, context?: any): import("leaflet").Renderer;
                (type: "locationfound", fn: import("leaflet").LocationEventHandlerFn, context?: any): import("leaflet").Renderer;
                (type: "click" | "contextmenu" | "dblclick" | "mousedown" | "mousemove" | "mouseout" | "mouseover" | "mouseup" | "preclick", fn: import("leaflet").LeafletMouseEventHandlerFn, context?: any): import("leaflet").Renderer;
                (type: "keydown" | "keypress" | "keyup", fn: import("leaflet").LeafletKeyboardEventHandlerFn, context?: any): import("leaflet").Renderer;
                (type: "zoomanim", fn: import("leaflet").ZoomAnimEventHandlerFn, context?: any): import("leaflet").Renderer;
                (type: "dragend", fn: import("leaflet").DragEndEventHandlerFn, context?: any): import("leaflet").Renderer;
                (type: "tileunload" | "tileloadstart" | "tileload" | "tileabort", fn: import("leaflet").TileEventHandlerFn, context?: any): import("leaflet").Renderer;
                (type: "tileerror", fn: import("leaflet").TileErrorEventHandlerFn, context?: any): import("leaflet").Renderer;
                (type: string, fn: import("leaflet").LeafletEventHandlerFn, context?: any): import("leaflet").Renderer;
                (eventMap: import("leaflet").LeafletEventHandlerFnMap): import("leaflet").Renderer;
            };
            fireEvent: (type: string, data?: any, propagate?: boolean | undefined) => import("leaflet").Renderer;
            hasEventListeners: (type: string) => boolean;
        } | undefined;
        fadeAnimation?: boolean | undefined;
        markerZoomAnimation?: boolean | undefined;
        transform3DLimit?: number | undefined;
        zoomAnimation?: boolean | undefined;
        zoomAnimationThreshold?: number | undefined;
        inertia?: boolean | undefined;
        inertiaDeceleration?: number | undefined;
        inertiaMaxSpeed?: number | undefined;
        easeLinearity?: number | undefined;
        worldCopyJump?: boolean | undefined;
        maxBoundsViscosity?: number | undefined;
        keyboard?: boolean | undefined;
        keyboardPanDelta?: number | undefined;
        scrollWheelZoom?: import("leaflet").Zoom | undefined;
        wheelDebounceTime?: number | undefined;
        wheelPxPerZoomLevel?: number | undefined;
        tap?: boolean | undefined;
        tapTolerance?: number | undefined;
        touchZoom?: import("leaflet").Zoom | undefined;
        bounceAtZoomLimits?: boolean | undefined;
    };
    on: {
        (type: "baselayerchange" | "overlayadd" | "overlayremove", fn: import("leaflet").LayersControlEventHandlerFn, context?: any): Map;
        (type: "layeradd" | "layerremove", fn: import("leaflet").LayerEventHandlerFn, context?: any): Map;
        (type: "drag" | "dragstart" | "error" | "load" | "unload" | "zoom" | "remove" | "zoomlevelschange" | "viewreset" | "zoomstart" | "movestart" | "move" | "zoomend" | "moveend" | "autopanstart" | "add" | "loading" | "update" | "down" | "predrag", fn: import("leaflet").LeafletEventHandlerFn, context?: any): Map;
        (type: "resize", fn: import("leaflet").ResizeEventHandlerFn, context?: any): Map;
        (type: "popupopen" | "popupclose", fn: import("leaflet").PopupEventHandlerFn, context?: any): Map;
        (type: "tooltipopen" | "tooltipclose", fn: import("leaflet").TooltipEventHandlerFn, context?: any): Map;
        (type: "locationerror", fn: import("leaflet").ErrorEventHandlerFn, context?: any): Map;
        (type: "locationfound", fn: import("leaflet").LocationEventHandlerFn, context?: any): Map;
        (type: "click" | "contextmenu" | "dblclick" | "mousedown" | "mousemove" | "mouseout" | "mouseover" | "mouseup" | "preclick", fn: import("leaflet").LeafletMouseEventHandlerFn, context?: any): Map;
        (type: "keydown" | "keypress" | "keyup", fn: import("leaflet").LeafletKeyboardEventHandlerFn, context?: any): Map;
        (type: "zoomanim", fn: import("leaflet").ZoomAnimEventHandlerFn, context?: any): Map;
        (type: "dragend", fn: import("leaflet").DragEndEventHandlerFn, context?: any): Map;
        (type: "tileunload" | "tileloadstart" | "tileload" | "tileabort", fn: import("leaflet").TileEventHandlerFn, context?: any): Map;
        (type: "tileerror", fn: import("leaflet").TileErrorEventHandlerFn, context?: any): Map;
        (type: string, fn: import("leaflet").LeafletEventHandlerFn, context?: any): Map;
        (eventMap: import("leaflet").LeafletEventHandlerFnMap): Map;
    };
    off: {
        (type: "baselayerchange" | "overlayadd" | "overlayremove", fn?: import("leaflet").LayersControlEventHandlerFn | undefined, context?: any): Map;
        (type: "layeradd" | "layerremove", fn?: import("leaflet").LayerEventHandlerFn | undefined, context?: any): Map;
        (type: "drag" | "dragstart" | "error" | "load" | "unload" | "zoom" | "remove" | "zoomlevelschange" | "viewreset" | "zoomstart" | "movestart" | "move" | "zoomend" | "moveend" | "autopanstart" | "add" | "loading" | "update" | "down" | "predrag", fn?: import("leaflet").LeafletEventHandlerFn | undefined, context?: any): Map;
        (type: "resize", fn?: import("leaflet").ResizeEventHandlerFn | undefined, context?: any): Map;
        (type: "popupopen" | "popupclose", fn?: import("leaflet").PopupEventHandlerFn | undefined, context?: any): Map;
        (type: "tooltipopen" | "tooltipclose", fn?: import("leaflet").TooltipEventHandlerFn | undefined, context?: any): Map;
        (type: "locationerror", fn?: import("leaflet").ErrorEventHandlerFn | undefined, context?: any): Map;
        (type: "locationfound", fn?: import("leaflet").LocationEventHandlerFn | undefined, context?: any): Map;
        (type: "click" | "contextmenu" | "dblclick" | "mousedown" | "mousemove" | "mouseout" | "mouseover" | "mouseup" | "preclick", fn?: import("leaflet").LeafletMouseEventHandlerFn | undefined, context?: any): Map;
        (type: "keydown" | "keypress" | "keyup", fn?: import("leaflet").LeafletKeyboardEventHandlerFn | undefined, context?: any): Map;
        (type: "zoomanim", fn?: import("leaflet").ZoomAnimEventHandlerFn | undefined, context?: any): Map;
        (type: "dragend", fn?: import("leaflet").DragEndEventHandlerFn | undefined, context?: any): Map;
        (type: "tileunload" | "tileloadstart" | "tileload" | "tileabort", fn?: import("leaflet").TileEventHandlerFn | undefined, context?: any): Map;
        (type: "tileerror", fn?: import("leaflet").TileErrorEventHandlerFn | undefined, context?: any): Map;
        (type: string, fn?: import("leaflet").LeafletEventHandlerFn | undefined, context?: any): Map;
        (eventMap: import("leaflet").LeafletEventHandlerFnMap): Map;
        (): Map;
    };
    fire: (type: string, data?: any, propagate?: boolean | undefined) => Map;
    listens: {
        (type: "click" | "contextmenu" | "dblclick" | "drag" | "dragend" | "dragstart" | "error" | "keydown" | "keypress" | "keyup" | "load" | "mousedown" | "mousemove" | "mouseout" | "mouseover" | "mouseup" | "resize" | "unload" | "zoom" | "remove" | "baselayerchange" | "overlayadd" | "overlayremove" | "layeradd" | "layerremove" | "zoomlevelschange" | "viewreset" | "zoomstart" | "movestart" | "move" | "zoomend" | "moveend" | "autopanstart" | "add" | "loading" | "update" | "down" | "predrag" | "popupopen" | "tooltipopen" | "tooltipclose" | "locationerror" | "locationfound" | "preclick" | "zoomanim" | "tileunload" | "tileloadstart" | "tileload" | "tileabort" | "tileerror", propagate?: boolean | undefined): boolean;
        (type: "baselayerchange" | "overlayadd" | "overlayremove", fn: import("leaflet").LayersControlEventHandlerFn, context?: any, propagate?: boolean | undefined): boolean;
        (type: "layeradd" | "layerremove", fn: import("leaflet").LayerEventHandlerFn, context?: any, propagate?: boolean | undefined): boolean;
        (type: "drag" | "dragstart" | "error" | "load" | "unload" | "zoom" | "remove" | "zoomlevelschange" | "viewreset" | "zoomstart" | "movestart" | "move" | "zoomend" | "moveend" | "autopanstart" | "add" | "loading" | "update" | "down" | "predrag", fn: import("leaflet").LeafletEventHandlerFn, context?: any, propagate?: boolean | undefined): boolean;
        (type: "resize", fn: import("leaflet").ResizeEventHandlerFn, context?: any, propagate?: boolean | undefined): boolean;
        (type: "popupopen" | "popupclose", fn: import("leaflet").PopupEventHandlerFn, context?: any, propagate?: boolean | undefined): boolean;
        (type: "tooltipopen" | "tooltipclose", fn: import("leaflet").TooltipEventHandlerFn, context?: any, propagate?: boolean | undefined): boolean;
        (type: "locationerror", fn: import("leaflet").ErrorEventHandlerFn, context?: any, propagate?: boolean | undefined): boolean;
        (type: "locationfound", fn: import("leaflet").LocationEventHandlerFn, context?: any, propagate?: boolean | undefined): boolean;
        (type: "click" | "contextmenu" | "dblclick" | "mousedown" | "mousemove" | "mouseout" | "mouseover" | "mouseup" | "preclick", fn: import("leaflet").LeafletMouseEventHandlerFn, context?: any, propagate?: boolean | undefined): boolean;
        (type: "keydown" | "keypress" | "keyup", fn: import("leaflet").LeafletKeyboardEventHandlerFn, context?: any, propagate?: boolean | undefined): boolean;
        (type: "zoomanim", fn: import("leaflet").ZoomAnimEventHandlerFn, context?: any, propagate?: boolean | undefined): boolean;
        (type: "dragend", fn: import("leaflet").DragEndEventHandlerFn, context?: any, propagate?: boolean | undefined): boolean;
        (type: "tileunload" | "tileloadstart" | "tileload" | "tileabort", fn: import("leaflet").TileEventHandlerFn, context?: any, propagate?: boolean | undefined): boolean;
        (type: "tileerror", fn: import("leaflet").TileEventHandlerFn, context?: any, propagate?: boolean | undefined): boolean;
        (type: string, fn: import("leaflet").LeafletEventHandlerFn, context?: any, propagate?: boolean | undefined): boolean;
    };
    once: {
        (type: "baselayerchange" | "overlayadd" | "overlayremove", fn: import("leaflet").LayersControlEventHandlerFn, context?: any): Map;
        (type: "layeradd" | "layerremove", fn: import("leaflet").LayerEventHandlerFn, context?: any): Map;
        (type: "drag" | "dragstart" | "error" | "load" | "unload" | "zoom" | "remove" | "zoomlevelschange" | "viewreset" | "zoomstart" | "movestart" | "move" | "zoomend" | "moveend" | "autopanstart" | "add" | "loading" | "update" | "down" | "predrag", fn: import("leaflet").LeafletEventHandlerFn, context?: any): Map;
        (type: "resize", fn: import("leaflet").ResizeEventHandlerFn, context?: any): Map;
        (type: "popupopen" | "popupclose", fn: import("leaflet").PopupEventHandlerFn, context?: any): Map;
        (type: "tooltipopen" | "tooltipclose", fn: import("leaflet").TooltipEventHandlerFn, context?: any): Map;
        (type: "locationerror", fn: import("leaflet").ErrorEventHandlerFn, context?: any): Map;
        (type: "locationfound", fn: import("leaflet").LocationEventHandlerFn, context?: any): Map;
        (type: "click" | "contextmenu" | "dblclick" | "mousedown" | "mousemove" | "mouseout" | "mouseover" | "mouseup" | "preclick", fn: import("leaflet").LeafletMouseEventHandlerFn, context?: any): Map;
        (type: "keydown" | "keypress" | "keyup", fn: import("leaflet").LeafletKeyboardEventHandlerFn, context?: any): Map;
        (type: "zoomanim", fn: import("leaflet").ZoomAnimEventHandlerFn, context?: any): Map;
        (type: "dragend", fn: import("leaflet").DragEndEventHandlerFn, context?: any): Map;
        (type: "tileunload" | "tileloadstart" | "tileload" | "tileabort", fn: import("leaflet").TileEventHandlerFn, context?: any): Map;
        (type: "tileerror", fn: import("leaflet").TileEventHandlerFn, context?: any): Map;
        (type: string, fn: import("leaflet").LeafletEventHandlerFn, context?: any): Map;
        (eventMap: import("leaflet").LeafletEventHandlerFnMap): Map;
    };
    addEventParent: (obj: import("leaflet").Evented) => Map;
    removeEventParent: (obj: import("leaflet").Evented) => Map;
    addEventListener: {
        (type: "baselayerchange" | "overlayadd" | "overlayremove", fn: import("leaflet").LayersControlEventHandlerFn, context?: any): Map;
        (type: "layeradd" | "layerremove", fn: import("leaflet").LayerEventHandlerFn, context?: any): Map;
        (type: "drag" | "dragstart" | "error" | "load" | "unload" | "zoom" | "remove" | "zoomlevelschange" | "viewreset" | "zoomstart" | "movestart" | "move" | "zoomend" | "moveend" | "autopanstart" | "add" | "loading" | "update" | "down" | "predrag", fn: import("leaflet").LeafletEventHandlerFn, context?: any): Map;
        (type: "resize", fn: import("leaflet").ResizeEventHandlerFn, context?: any): Map;
        (type: "popupopen" | "popupclose", fn: import("leaflet").PopupEventHandlerFn, context?: any): Map;
        (type: "tooltipopen" | "tooltipclose", fn: import("leaflet").TooltipEventHandlerFn, context?: any): Map;
        (type: "locationerror", fn: import("leaflet").ErrorEventHandlerFn, context?: any): Map;
        (type: "locationfound", fn: import("leaflet").LocationEventHandlerFn, context?: any): Map;
        (type: "click" | "contextmenu" | "dblclick" | "mousedown" | "mousemove" | "mouseout" | "mouseover" | "mouseup" | "preclick", fn: import("leaflet").LeafletMouseEventHandlerFn, context?: any): Map;
        (type: "keydown" | "keypress" | "keyup", fn: import("leaflet").LeafletKeyboardEventHandlerFn, context?: any): Map;
        (type: "zoomanim", fn: import("leaflet").ZoomAnimEventHandlerFn, context?: any): Map;
        (type: "dragend", fn: import("leaflet").DragEndEventHandlerFn, context?: any): Map;
        (type: "tileunload" | "tileloadstart" | "tileload" | "tileabort", fn: import("leaflet").TileEventHandlerFn, context?: any): Map;
        (type: "tileerror", fn: import("leaflet").TileErrorEventHandlerFn, context?: any): Map;
        (type: string, fn: import("leaflet").LeafletEventHandlerFn, context?: any): Map;
        (eventMap: import("leaflet").LeafletEventHandlerFnMap): Map;
    };
    removeEventListener: {
        (type: "baselayerchange" | "overlayadd" | "overlayremove", fn?: import("leaflet").LayersControlEventHandlerFn | undefined, context?: any): Map;
        (type: "layeradd" | "layerremove", fn?: import("leaflet").LayerEventHandlerFn | undefined, context?: any): Map;
        (type: "drag" | "dragstart" | "error" | "load" | "unload" | "zoom" | "remove" | "zoomlevelschange" | "viewreset" | "zoomstart" | "movestart" | "move" | "zoomend" | "moveend" | "autopanstart" | "add" | "loading" | "update" | "down" | "predrag", fn?: import("leaflet").LeafletEventHandlerFn | undefined, context?: any): Map;
        (type: "resize", fn?: import("leaflet").ResizeEventHandlerFn | undefined, context?: any): Map;
        (type: "popupopen" | "popupclose", fn?: import("leaflet").PopupEventHandlerFn | undefined, context?: any): Map;
        (type: "tooltipopen" | "tooltipclose", fn?: import("leaflet").TooltipEventHandlerFn | undefined, context?: any): Map;
        (type: "locationerror", fn?: import("leaflet").ErrorEventHandlerFn | undefined, context?: any): Map;
        (type: "locationfound", fn?: import("leaflet").LocationEventHandlerFn | undefined, context?: any): Map;
        (type: "click" | "contextmenu" | "dblclick" | "mousedown" | "mousemove" | "mouseout" | "mouseover" | "mouseup" | "preclick", fn?: import("leaflet").LeafletMouseEventHandlerFn | undefined, context?: any): Map;
        (type: "keydown" | "keypress" | "keyup", fn?: import("leaflet").LeafletKeyboardEventHandlerFn | undefined, context?: any): Map;
        (type: "zoomanim", fn?: import("leaflet").ZoomAnimEventHandlerFn | undefined, context?: any): Map;
        (type: "dragend", fn?: import("leaflet").DragEndEventHandlerFn | undefined, context?: any): Map;
        (type: "tileunload" | "tileloadstart" | "tileload" | "tileabort", fn?: import("leaflet").TileEventHandlerFn | undefined, context?: any): Map;
        (type: "tileerror", fn?: import("leaflet").TileErrorEventHandlerFn | undefined, context?: any): Map;
        (type: string, fn?: import("leaflet").LeafletEventHandlerFn | undefined, context?: any): Map;
        (eventMap: import("leaflet").LeafletEventHandlerFnMap): Map;
    };
    clearAllEventListeners: () => Map;
    addOneTimeEventListener: {
        (type: "baselayerchange" | "overlayadd" | "overlayremove", fn: import("leaflet").LayersControlEventHandlerFn, context?: any): Map;
        (type: "layeradd" | "layerremove", fn: import("leaflet").LayerEventHandlerFn, context?: any): Map;
        (type: "drag" | "dragstart" | "error" | "load" | "unload" | "zoom" | "remove" | "zoomlevelschange" | "viewreset" | "zoomstart" | "movestart" | "move" | "zoomend" | "moveend" | "autopanstart" | "add" | "loading" | "update" | "down" | "predrag", fn: import("leaflet").LeafletEventHandlerFn, context?: any): Map;
        (type: "resize", fn: import("leaflet").ResizeEventHandlerFn, context?: any): Map;
        (type: "popupopen" | "popupclose", fn: import("leaflet").PopupEventHandlerFn, context?: any): Map;
        (type: "tooltipopen" | "tooltipclose", fn: import("leaflet").TooltipEventHandlerFn, context?: any): Map;
        (type: "locationerror", fn: import("leaflet").ErrorEventHandlerFn, context?: any): Map;
        (type: "locationfound", fn: import("leaflet").LocationEventHandlerFn, context?: any): Map;
        (type: "click" | "contextmenu" | "dblclick" | "mousedown" | "mousemove" | "mouseout" | "mouseover" | "mouseup" | "preclick", fn: import("leaflet").LeafletMouseEventHandlerFn, context?: any): Map;
        (type: "keydown" | "keypress" | "keyup", fn: import("leaflet").LeafletKeyboardEventHandlerFn, context?: any): Map;
        (type: "zoomanim", fn: import("leaflet").ZoomAnimEventHandlerFn, context?: any): Map;
        (type: "dragend", fn: import("leaflet").DragEndEventHandlerFn, context?: any): Map;
        (type: "tileunload" | "tileloadstart" | "tileload" | "tileabort", fn: import("leaflet").TileEventHandlerFn, context?: any): Map;
        (type: "tileerror", fn: import("leaflet").TileErrorEventHandlerFn, context?: any): Map;
        (type: string, fn: import("leaflet").LeafletEventHandlerFn, context?: any): Map;
        (eventMap: import("leaflet").LeafletEventHandlerFnMap): Map;
    };
    fireEvent: (type: string, data?: any, propagate?: boolean | undefined) => Map;
    hasEventListeners: (type: string) => boolean;
} | null>;
export type UseLeafletMapReturn = ReturnType<typeof useLeafletMap>;
